## ==================================================== ##
##  ___ _  _ _  _ _  _  __  ___  _  _ ___ __    __ ____ ##
## / __) )( ) \/ ) \/ )(  )(  ,)( \/ )  ,\  )  /  \_  _)##
## \__ \)()( )  ( )  ( /__\ )  \ \  / ) _/)(__( () ))(  ##
## (___/\__/(/\/\)/\/\)_)(_)_)\_)__/ (_) (____)\__/(__) ##
##                                                      ##
##  Summary Plot                                        ##
##  Written by Kristin Potter                           ##
##  http://www.sci.utah.edu/~kpotter/software/sumplots/ ##
##  Copywrite 2010  kpotter@sci.utah.edu                ##
## ==================================================== ##

## ---------------------------------------------------- ##
## Create a full summary plot
## ---------------------------------------------------- ##
summaryplot<-function(data, newpage=TRUE, width=NULL, show=TRUE,...)
  {
    ## Convert the data into a matrix
    data = as.matrix(data)
    
    # Get the dimensions of the plots 
    dims = findPlotDimensions(data,width)
       
    ## create the densityplot
    sdp = symdenplot(data, newpage=FALSE, show=FALSE, dims = dims,...)
    
    ## create the abbreviated box plot
    abp = abbrvboxplot(data, newpage=FALSE, show=FALSE, dims = dims,...)

    ## moment plot
    mp = momentplot(data, newpage=FALSE, show=FALSE, dims=dims,...)

    ## distribution fitting plot
    dfp = distribplot(data, newpage=FALSE, show=FALSE, dims=dims,...)
    
    ## create the summary plot structure
    obj <- structure(list(data=data,
                          abbrvboxplot=abp, showabbrv = TRUE,
                          symdenplot=sdp, showden = TRUE,
                          momentplot=mp, showmp = TRUE,
                          distribplot=dfp, showdfp=TRUE,
                          dims=dims,newpage=newpage), class="summaryplot")

    ## if we want to display
    if(show)
      plot(obj)

    ## silently return
    invisible(obj)
  }

## ---------------------------------------------------- ##
## Plot the summary plots
## ---------------------------------------------------- ##
plot.summaryplot<-function(x,...)
  {    
    ## create a new grid, if requested
    if(x$newpage)
      setupView(x$dims$xRange, x$dims$yRange)
    
    ## plot the density plot
    if(x$showden)
      plot(x$symdenplot,...)
    
    ## plot the abbreviatied box plot
    if(x$showabbrv)
      plot(x$abbrvboxplot,...)    

    ## plot the moment plot
    if(x$showmp)
      plot(x$momentplot,...)

    ## plot the distribution fitting plot
    if(x$showdfp)
      plot(x$distribplot,...)
    
    ## break down the grid, if requested
    if(x$newpage)
      breakdownView()
  }
