## ---------------------------------------------------- ##
## Find the height/width
## ---------------------------------------------------- ##
findPlotDimensions <- function(data, width)
  {   
    ## find the min and max data values
    minD = min(data, na.rm=TRUE)
    maxD = max(data, na.rm=TRUE)
    minW = 0.0
   # maxW = length(data)-((1/length(data))/4)
    maxW = ncol(data)-((1/ncol(data))/4)
    
    ## find the range of the values
    xRange = c(0.5, ncol(data)+0.5)
    yRange = c(minD, maxD)

    ## find the maximum width
    maxWidth = 2
        
    ## find the width of the plots
    if(missing(width) || is.null(width))
      width = (1/ncol(data))+((ncol(data)-1)*(1/ncol(data))/2)
    else
      if(width > maxWidth)
        width = maxWidth
    
    ## find the height equal to the length of the crossbars
    height = (maxD-minD)*(width-minW)/(maxW-minW)+minD
        
    ## return the dimensions
    dims = list(width=width, height=height, xRange=xRange, yRange=yRange)
    return(dims)
  }

## ---------------------------------------------------- ##
## Set up the viewing
## ---------------------------------------------------- ##
setupView<-function(xRange, yRange)
  {
    ## create a new grid to draw into
    grid.newpage()
    
    ## create the margins around the plot
    pushViewport(plotViewport(c(5, 4, 2, 2)))
     
    ## create the viewport for the plot using the # of data sets
    ## and the entire range of the data
    pushViewport(dataViewport(xRange, yRange, name="plotregion"))
  }

## ---------------------------------------------------- ##
## Break down the viewing
## ---------------------------------------------------- ##
breakdownView<-function()
  {
    grid.rect()
    grid.xaxis()
    grid.yaxis()
    popViewport(2) 
  }
