\name{summaryplot}
\alias{summaryplot}
\alias{plot.summaryplot}
\title{Summary Plots}
\description{ Create a summary plot which consists of an abbreviated box
  plot, a symmetric density plot, a moment plot and a distribution plot.}
\usage{
summaryplot(data, newpage=TRUE, width=NULL, show=TRUE,...)
\method{plot}{summaryplot}(x,...)
}
\arguments{
  \item{data}{A 1D data set.}
  \item{newpage}{Option to create a new plot, or add to an already
    existing plot if newpage=FALSE.}
  \item{width}{The width of the plot, used to adjust the look of the
    plot.}
  \item{show}{If set to false, the summary plots will be computed but not
    plotted.} 
  \item{x}{The summary plot object.}
  \item{...}{additional args have no effect}
}
\value{ An object of class \code{summaryplot} creates a collection of
  summary-type plots. The object
\code{summaryplot} consists of the following components:
\item{abbrvboxplot}{The abbreviated box plot object.}
\item{showabbrv}{Option to show the abbreviated box plot.}
\item{symdenplot}{The symmetric density plot object.}
\item{showden}{Option to show the density plot.}
\item{momentplot}{The moment plot.}
\item{showmp}{Option to show the moment plot.}
\item{distribplot}{The distribution fitting plot.}
\item{showdfp}{Option to show the distribution fit plot.}
\item{dims}{The spatial dimensions of the plot.}
\item{newpage}{Option to display on a new plot (newplot=TRUE), or within
an existing plot (newpage=FALSE).}
}
\author{Kristin Potter}
\seealso{
\code{\link{abbrvboxplot}},
\code{\link{symdenplot}},
\code{\link{momentplot}},
\code{\link{distribplot}}
}
\references{
Visualizing Summary Statistics and Uncertainty.
Kristin Potter, Joe Kniss, Richard Riesenfeld, and Chris R. Johnson.
In Computer Graphics Forum (Proceedings of Eurovis 2010), Vol. 29, No. 3, pp. 823-831, 2010.
}
\examples{
library(sumplots)
r=rnorm(500)
e = rexp(500)
summaryplot(r)
}
\keyword{summary, boxplot, histogram}
