\name{symdenplot}
\alias{symdenplot}
\alias{compute.symdenplot}
\alias{plot.symdenplot}
\title{Symmetric Density Plot}
\description{Create a symmetric density plot from a data set which
  estimates the density of a data set and plots it across the y axis
  using quads and a colormap.}
\usage{
symdenplot(data, newpage=TRUE, width=NULL,outlinecolor="gray", linewidth=1.0, breaks="Sturges", colormap=NULL,show=TRUE, dims=NULL,...)
compute.symdenplot(x, width=NULL)
\method{plot}{symdenplot}(x, dims, compute=TRUE, ...)
}
\arguments{
  \item{data}{A 1D data set.}
  \item{newpage}{Option to create a new plot, or add to an already
    existing plot if newpage=FALSE.}
  \item{width}{The width of the plot, used to adjust the look of the
    plot.}
  \item{outlinecolor}{The color of the outline of the plot.}
  \item{linewidth}{The thickness of the line to display the plot.}
  \item{breaks}{The method to divide up the density estimator (from
    hist{graphics}).  Can be: a vector giving the breakpoints between histogram cells,
    a single number giving the number of cells for the histogram,
    a character string naming an algorithm to compute the number of cells, or
    a function to compute the number of cells.}
  \item{colormap}{The colormap for the density quads.}
  \item{show}{If set to false, the summary plots will be computed but not
    plotted.}
  \item{dims}{The dimension of the plot.}
  \item{compute}{Flag to recompute theg plot geometry.}
  \item{x}{The symdenplot object.}
  \item{...}{additional args have no effect}
}
\value{ An object of class \code{symdenplot} is used to create a
symmetric density plot to display the density of a data set. The object
\code{symdenplot} consists of the following components:
\item{data}{DO O need thigs?}
\item{dims}{The spatial dimensions of the plot}
\item{newpage}{Option to display on a new plot (newplot=TRUE), or within
an existing plot (newpage=FALSE)}
\item{look}{The look of the abbreviated box plot including the line
  color, width, and end-point style.}
\item{breaks}{The breaks as defined above.}
\item{colormap}{The colormap for the density quads.}
}
\author{Kristin Potter}
\seealso{
  \code{\link{summaryplot}},
  \code{\link{abbrvboxplot}},
  \code{\link{momentplot}},
  \code{\link{distribplot}}
}
\references{
  Visualizing Summary Statistics and Uncertainty.
  Kristin Potter, Joe Kniss, Richard Riesenfeld, and Chris R. Johnson.
  In Computer Graphics Forum (Proceedings of Eurovis 2010), Vol. 29,
  No. 3, pp. 823-831, 2010.
}
\examples{
library(sumplots)
r=rnorm(500)
e = rexp(500)
symdenplot(r)
}
\keyword{density estimation, histogram}